@@ -9,3 +9,5 @@ from . import topcoat
 from . import gae
 from . import gunicorn
 from . import jquery
+from . import angularjs
+from . import socketio
\ No newline at end of file
